@@ -34,8 +34,8 @@ class RailsIntegration:
         When this function is called, ``transaction.amount_in`` is the amount sent
         to the anchor, `not the amount specified in a SEP-24 or SEP-31 API call`.
         This matters because the amount actually sent to the anchor may differ from
-        the amount specified in an API call. If the amount differs from the original
-        amount but is still valid, do not forget to recalculate ``amount_fee``.
+        the amount specified in an API call. That is why you should always validate
+        ``transaction.amount_in`` and calculate ``transaction.amount_fee`` here.
 
         If the amount is invalid in some way, the anchor must choose how to handle it.
         If you choose to refund the payment in its entirety, change ``transaction.status``
@@ -60,17 +60,18 @@ class RailsIntegration:
 
         If ``transaction.protocol == Transaction.PROTOCOL.sep31`` and more information
         is required from the sending anchor or user to complete the transaction, update
-        the status to ``Transaction.STATUS.pending_info_update`` and save a JSON-serialized
-        string of the missing fields to the ``Transaction.required_info_update`` column.
-        The JSON string should be in the format returned from ``SendIntegration.info()``.
-        You can also optionally save a human-readable message to
+        the status to ``Transaction.STATUS.pending_transaction_info_update`` and save a
+        JSON-serialized string containing the fields that need updating to the
+        ``Transaction.required_info_update`` column. The JSON string should be in the
+        format returned from ``SEP31ReceiverIntegration.info()``. You can also
+        optionally save a human-readable message to
         ``Transaction.required_info_message``. Both fields will included in the
         `/transaction` response requested by the sending anchor.
 
         If the SEP-31 transaction is waiting for an update, the sending anchor will
-        eventually make a request to the `/update` endpoint with the information
-        specified in ``Transaction.required_info_update``. Once updated, this function
-        will be called again with the updated transaction.
+        eventually make a request to the `PATCH /transaction` endpoint with the
+        information specified in ``Transaction.required_info_update``. Once updated,
+        this function will be called again with the updated transaction.
 
         :param transaction: the ``Transaction`` object associated with the payment
             this function should make
