@@ -53,7 +53,7 @@ class DepositIntegration:
         ::
 
             def form_for_transaction(self, transaction, post_data = None, amount = None):
-                if not transaction.amount_in:
+                if transaction.amount_in:
                     return
                 elif post_data:
                     return TransactionForm(transaction, post_data)
@@ -366,7 +366,7 @@ class WithdrawalIntegration:
         """
         pass
 
-    def after_form_validation(self, form: TransactionForm, transaction: Transaction):
+    def after_form_validation(self, form: forms.Form, transaction: Transaction):
         """
         Same as ``DepositIntegration.after_form_validation``, except
         `transaction.to_address` should be saved here when present in `form`.
